==> trade-center-biz-0.2.7-ZDX-20161114.122234-1-sources.jar: cn/com/duiba/order/center/biz/service/consumerrecord/ConsumerExchangeRecordService.java <==
package cn.com.duiba.order.center.biz.service.consumerrecord;

import cn.com.duiba.order.center.api.dto.ConsumerExchangeRecordDto;
import cn.com.duiba.order.center.biz.constant.TopicConstant;
import cn.com.duiba.order.center.biz.entity.ConsumerExchangeRecordEntity;
import cn.com.duiba.order.center.biz.entity.ConsumerExchangeRecordSequenceEntity;
import cn.com.duiba.order.center.biz.entity.CrecordSyncMessage;
import cn.com.duiba.order.center.biz.handle.ConsumerExchangeRecordHandle;
import cn.com.duiba.order.center.biz.service.message.MessageService;
import cn.com.duiba.wolf.utils.BeanUtils;
import com.alibaba.fastjson.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by yansen on 16/9/30.
 */
@Service
public class ConsumerExchangeRecordService {

    private static Logger log = LoggerFactory.getLogger(ConsumerExchangeRecordService.class);


    @Autowired
    private TopicConstant topicConstant;
    @Autowired
    private MessageService messageService;

    @Autowired
    private ConsumerExchangeRecordHandle consumerExchangeRecordHandle;
    public void insert(ConsumerExchangeRecordDto consumerExchangeRecordDto) {
        ConsumerExchangeRecordEntity entity= BeanUtils.copy(consumerExchangeRecordDto,ConsumerExchangeRecordEntity.class);
        entity.setId(getSequenceID(new ConsumerExchangeRecordSequenceEntity()));
        consumerExchangeRecordHandle.insert(entity);
        consumerExchangeRecordDto.setId(entity.getId());
        sendSyncMessage(entity.getConsumerId(),entity.getId());
    }

    private long getSequenceID(ConsumerExchangeRecordSequenceEntity consumerExchangeRecordSequenceEntity) {
        consumerExchangeRecordHandle.getSequenceID(consumerExchangeRecordSequenceEntity);
        return consumerExchangeRecordSequenceEntity.getId();
    }

    public void sendSyncMessage(Long consumerId, Long id) {
        try {
            CrecordSyncMessage message = new CrecordSyncMessage();
            message.setConsumerId(consumerId);
            message.setId(id);
            String body = JSONObject.toJSONString(message);
            messageService.sendMsg(topicConstant.getTopicCrecord(), body);
        } catch (Exception e) {
            log.error("sendSyncMessage error: [consumerId " + consumerId + "] [crecordId " + id + "]", e);
        }
    }
}

==> trade-center-biz-0.5.4-ZDX-20161221.123948-1-sources.jar: cn/com/duiba/order/center/biz/service/consumerrecord/ConsumerExchangeRecordService.java <==
package cn.com.duiba.order.center.biz.service.consumerrecord;

import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;

import cn.com.duiba.boot.ext.autoconfigure.logger.JsonLoggerFactory;
import cn.com.duiba.order.center.api.dto.ConsumerExchangeRecordDto;
import cn.com.duiba.order.center.biz.constant.TopicConstant;
import cn.com.duiba.order.center.biz.entity.ConsumerExchangeRecordEntity;
import cn.com.duiba.order.center.biz.entity.ConsumerExchangeRecordSequenceEntity;
import cn.com.duiba.order.center.biz.entity.CrecordSyncMessage;
import cn.com.duiba.order.center.biz.handle.ConsumerExchangeRecordHandle;
import cn.com.duiba.order.center.biz.service.message.MessageService;
import cn.com.duiba.wolf.utils.BeanUtils;

/**
 * Created by yansen on 16/9/30.
 */
@Service
public class ConsumerExchangeRecordService {

    private static Logger log = JsonLoggerFactory.getLogger(ConsumerExchangeRecordService.class);


    @Autowired
    private TopicConstant topicConstant;
    @Autowired
    private MessageService messageService;

    @Autowired
    private ConsumerExchangeRecordHandle consumerExchangeRecordHandle;

    /**
     *
     * @param consumerExchangeRecordDto
     */
    public void insert(ConsumerExchangeRecordDto consumerExchangeRecordDto) {
        ConsumerExchangeRecordEntity entity= BeanUtils.copy(consumerExchangeRecordDto,ConsumerExchangeRecordEntity.class);
        entity.setId(getSequenceID(new ConsumerExchangeRecordSequenceEntity()));
        consumerExchangeRecordHandle.insert(entity);
        consumerExchangeRecordDto.setId(entity.getId());
        sendSyncMessage(entity.getConsumerId(),entity.getId());
    }
    
	public ConsumerExchangeRecordEntity selectOneByMapCondition(Map<String, Object> map) {
		return consumerExchangeRecordHandle.selectOneByMapCondition(map);
	}

    /**
     *
     * @param map
     * @return
     */
	public List<ConsumerExchangeRecordEntity> selectListByMapCondition(Map<String, Object> map) {
		return consumerExchangeRecordHandle.selectListByMapCondition(map);
	}

    /**
     *
     * @param map
     * @return
     */
	public List<ConsumerExchangeRecordEntity> selectPageListByMapCondition(Map<String, Object> map) {
		return consumerExchangeRecordHandle.selectPageListByMapCondition(map);
	}

    /**
     *
     * @param entity
     * @return
     */
	public Boolean update(ConsumerExchangeRecordEntity entity) {
		int ret = consumerExchangeRecordHandle.update(entity);
		if(ret < 1){
			return false;
		}
		sendSyncMessage(entity.getConsumerId(),entity.getId());
		return true;
	}
    
    private long getSequenceID(ConsumerExchangeRecordSequenceEntity consumerExchangeRecordSequenceEntity) {
        consumerExchangeRecordHandle.getSequenceID(consumerExchangeRecordSequenceEntity);
        return consumerExchangeRecordSequenceEntity.getId();
    }

    private void sendSyncMessage(Long consumerId, Long id) {
        try {
            CrecordSyncMessage message = new CrecordSyncMessage();
            message.setConsumerId(consumerId);
            message.setId(id);
            String body = JSONObject.toJSONString(message);
            messageService.sendMsg(topicConstant.getTopicCrecord(), body);
        } catch (Exception e) {
            log.error("sendSyncMessage error: [consumerId " + consumerId + "] [crecordId " + id + "]", e);
        }
    }
}
